/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 */

const COLLECTION_DEFAULTS = require('../data/collectionDefaults')
const PLUGINS = require('../data/availablePlugins')

const TriggersUtil = {
  getCollectionJson: (plugins = []) => {
    const arrayOfCollectors = []

    for (const plugin of plugins) {
      if (PLUGINS.includes(plugin)) {
        const collectorJson = module.exports.getCollectorJson(plugin)
        arrayOfCollectors.push(collectorJson)
      }
    }
    return [arrayOfCollectors]
  },
  getCollectorJson: (name) => {
    return {
      Plugin: name,
      Options: COLLECTION_DEFAULTS[name]?.options
    }
  }
}

module.exports = TriggersUtil
